# AllayRT - Allay Runtime

AllayRT is a lightweight AI inference engine designed to execute and optimize (`.art`) models and applications.

## Quick Start

```python
from AllayRT import AllayRT

art = AllayRT()
model = art.read_model("model.art")
compiled_model = art.compile_model(model, "CPU")
out = compiled_model.run(img)
```